generate_rest

Function generate_rest 

pub fn generate_rest(request: &CodeGeneratorRequest) -> CodeGeneratorResponse
Generate a REST protoc plugin response for a request.

Errors are returned through the protoc plugin error field so buf generate and protoc can display them as compiler-plugin failures.