generate_ws

Function generate_ws 

pub fn generate_ws(request: &CodeGeneratorRequest) -> CodeGeneratorResponse
Generate a WebSocket protoc plugin response for a request.

Errors are returned through the protoc plugin error field so buf generate and protoc can display them as compiler-plugin failures.