pub struct CodeGeneratorResponse {
pub error: Option<String>,
pub supported_features: Option<u64>,
pub minimum_edition: Option<i32>,
pub maximum_edition: Option<i32>,
pub file: Vec<File>,
/* private fields */
}Expand description
The plugin writes an encoded CodeGeneratorResponse to stdout.
Fields
error: Option<String>Error message. If non-empty, code generation failed. The plugin process should exit with status code zero even if it reports an error in this way.
This should be used to indicate errors in .proto files which prevent the code generator from generating correct code. Errors which indicate a problem in protoc itself – such as the input CodeGeneratorRequest being unparseable – should be reported by writing a message to stderr and exiting with a non-zero status code.
Field 1: error
supported_features: Option<u64>A bitmask of supported features that the code generator supports. This is a bitwise “or” of values from the Feature enum.
Field 2: supported_features
minimum_edition: Option<i32>The minimum edition this plugin supports. This will be treated as an Edition enum, but we want to allow unknown values. It should be specified according the edition enum value, not the edition number. Only takes effect for plugins that have FEATURE_SUPPORTS_EDITIONS set.
Field 3: minimum_edition
maximum_edition: Option<i32>The maximum edition this plugin supports. This will be treated as an Edition enum, but we want to allow unknown values. It should be specified according the edition enum value, not the edition number. Only takes effect for plugins that have FEATURE_SUPPORTS_EDITIONS set.
Field 4: maximum_edition
file: Vec<File>Field 15: file
Implementations